<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Acknowledgements</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1094"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1098"/>
        <source>%1 is released under %2</source>
        <translation>%1 is released under %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Black</source>
        <translation>Black</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>White</source>
        <translation>White</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Dark Gray</source>
        <translation>Dark Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Light Gray</source>
        <translation>Light Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Red</source>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Green</source>
        <translation>Green</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Blue</source>
        <translation>Blue</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="920"/>
        <source>Yellow</source>
        <translation>Yellow</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="923"/>
        <source>Dark Red</source>
        <translation>Dark Red</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="926"/>
        <source>Dark Green</source>
        <translation>Dark Green</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="929"/>
        <source>Dark Blue</source>
        <translation>Dark Blue</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="932"/>
        <source>Dark Cyan</source>
        <translation>Dark Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="935"/>
        <source>Dark Magenta</source>
        <translation>Dark Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="938"/>
        <source>Dark Yellow</source>
        <translation>Dark Yellow</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="41"/>
        <source>Enter a new shortcut</source>
        <translation>Enter a new shortcut</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="460"/>
        <source>Stop reading</source>
        <translation>Stop reading</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="462"/>
        <source>Text to Speech</source>
        <translation>Text to Speech</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="485"/>
        <source>Translate</source>
        <translation>Translate</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="507"/>
        <source>Speech To Text</source>
        <translation>Speech To Text</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Cancel</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="284"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Replace</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Please input a new shortcut</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>None</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="155"/>
        <source>Stop reading</source>
        <translation>Stop reading</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="157"/>
        <source>Text to Speech</source>
        <translation>Text to Speech</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="180"/>
        <source>Translate</source>
        <translation>Translate</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Speech To Text</source>
        <translation>Speech To Text</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="190"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="212"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="213"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1049"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="229"/>
        <source>Basic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="244"/>
        <source>Printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
        <source>Copies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="279"/>
        <source>Page range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="282"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="283"/>
        <source>Current page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="284"/>
        <source>Select pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="299"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
        <source>Portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="333"/>
        <source>Landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="360"/>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="370"/>
        <source>Color mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="373"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1019"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1061"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="373"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1058"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1061"/>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="384"/>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="387"/>
        <source>Normal(mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="387"/>
        <source>Narrow(mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="387"/>
        <source>Moderate(mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="387"/>
        <source>Customize(mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="393"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="396"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="399"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="444"/>
        <source>Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="458"/>
        <source>Actual size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="467"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="497"/>
        <source>Paper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="507"/>
        <source>Paper size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="521"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="532"/>
        <source>Duplex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
        <source>Print to PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="849"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="856"/>
        <source>Flip on short edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="852"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="855"/>
        <source>Flip on long edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1024"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1109"/>
        <source>1-%1. For example, 1,3,5-7,11-15,18,21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1432"/>
        <source>Save as PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1432"/>
        <source>PDF file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="443"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
        <source>No search result</source>
        <translation>No search result</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="323"/>
        <source>Restore Defaults</source>
        <translation>Restore Defaults</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="147"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Please enter a new shortcut</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="510"/>
        <source>Theme</source>
        <translation>Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="511"/>
        <source>Light Theme</source>
        <translation>Light Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="512"/>
        <source>Dark Theme</source>
        <translation>Dark Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="513"/>
        <source>System Theme</source>
        <translation>System Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="537"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="544"/>
        <source>About</source>
        <translation>About</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="551"/>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
</TS>
